@@ -1,11 +1,11 @@
 from __future__ import division, print_function, absolute_import
 
-import warnings
-
 import numpy as np
-from numpy.testing import TestCase, run_module_suite, assert_raises, \
-        assert_almost_equal, assert_array_almost_equal, assert_equal, \
-        assert_, assert_allclose, assert_warns
+from numpy.testing import (assert_almost_equal, assert_array_almost_equal,
+                           assert_equal, assert_,
+                           assert_allclose, assert_warns)
+from pytest import raises as assert_raises
+
 from scipy.special import sinc
 
 from scipy.signal import kaiser_beta, kaiser_atten, kaiserord, \
@@ -36,7 +36,7 @@ def test_kaiserord():
     assert_equal((numtaps, beta), (2, 0.0))
 
 
-class TestFirwin(TestCase):
+class TestFirwin(object):
 
     def check_response(self, h, expected_response, tol=.05):
         N = len(h)
@@ -45,7 +45,7 @@ class TestFirwin(TestCase):
         for freq, expected in expected_response:
             actual = abs(np.sum(h*np.exp(-1.j*np.pi*m*freq)))
             mse = abs(actual-expected)**2
-            self.assertTrue(mse < tol, 'response not as expected, mse=%g > %g'
+            assert_(mse < tol, 'response not as expected, mse=%g > %g'
                % (mse, tol))
 
     def test_response(self):
@@ -120,12 +120,12 @@ class TestFirwin(TestCase):
                     cutoff = [0] + cutoff
                 else:
                     cutoff = cutoff + [1]
-            self.assertTrue(self.mse(h, [cutoff]) < self.mse(hs, [cutoff]),
+            assert_(self.mse(h, [cutoff]) < self.mse(hs, [cutoff]),
                 'least squares violation')
             self.check_response(hs, [expected_response], 1e-12)
 
 
-class TestFirWinMore(TestCase):
+class TestFirWinMore(object):
     """Different author, different style, different tests..."""
 
     def test_lowpass(self):
@@ -195,14 +195,14 @@ class TestFirWinMore(TestCase):
                 [1.0, 1.0, 1.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0],
                 decimal=5)
 
-    def test_nyq(self):
-        """Test the nyq keyword."""
+    def test_fs_nyq(self):
+        """Test the fs and nyq keywords."""
         nyquist = 1000
         width = 40.0
         relative_width = width/nyquist
         ntaps, beta = kaiserord(120, relative_width)
         taps = firwin(ntaps, cutoff=[300, 700], window=('kaiser', beta),
-                        pass_zero=False, scale=False, nyq=nyquist)
+                        pass_zero=False, scale=False, fs=2*nyquist)
 
         # Check the symmetry of taps.
         assert_array_almost_equal(taps[:ntaps//2], taps[ntaps:ntaps-ntaps//2-1:-1])
@@ -214,6 +214,10 @@ class TestFirWinMore(TestCase):
         assert_array_almost_equal(np.abs(response),
                 [0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 0.0, 0.0, 0.0], decimal=5)
 
+        taps2 = firwin(ntaps, cutoff=[300, 700], window=('kaiser', beta),
+                        pass_zero=False, scale=False, nyq=nyquist)
+        assert_allclose(taps2, taps)
+
     def test_bad_cutoff(self):
         """Test that invalid cutoff argument raises ValueError."""
         # cutoff values must be greater than 0 and less than 1.
@@ -232,6 +236,8 @@ class TestFirWinMore(TestCase):
         # cutoff values must be less than nyq.
         assert_raises(ValueError, firwin, 99, 50.0, nyq=40)
         assert_raises(ValueError, firwin, 99, [10, 20, 30], nyq=25)
+        assert_raises(ValueError, firwin, 99, 50.0, fs=80)
+        assert_raises(ValueError, firwin, 99, [10, 20, 30], fs=50)
 
     def test_even_highpass_raises_value_error(self):
         """Test that attempt to create a highpass filter with an even number
@@ -240,7 +246,7 @@ class TestFirWinMore(TestCase):
         assert_raises(ValueError, firwin, 40, [.25, 0.5])
 
 
-class TestFirwin2(TestCase):
+class TestFirwin2(object):
 
     def test_invalid_args(self):
         # `freq` and `gain` have different lengths.
@@ -255,7 +261,7 @@ class TestFirwin2(TestCase):
         # `freq` does not start at 0.0.
         assert_raises(ValueError, firwin2, 50, [0.5, 1.0], [0.0, 1.0])
 
-        # Type II filter, but the gain at nyquist rate is not zero.
+        # Type II filter, but the gain at nyquist frequency is not zero.
         assert_raises(ValueError, firwin2, 16, [0.0, 0.5, 1.0], [0.0, 1.0, 1.0])
 
         # Type III filter, but the gains at nyquist and zero rate are not zero.
@@ -351,13 +357,14 @@ class TestFirwin2(TestCase):
         response2 = np.interp(freqs / np.pi, freq, gain)
         assert_array_almost_equal(abs(response1), response2, decimal=3)
 
-    def test_nyq(self):
+    def test_fs_nyq(self):
         taps1 = firwin2(80, [0.0, 0.5, 1.0], [1.0, 1.0, 0.0])
+        taps2 = firwin2(80, [0.0, 30.0, 60.0], [1.0, 1.0, 0.0], fs=120.0)
+        assert_array_almost_equal(taps1, taps2)
         taps2 = firwin2(80, [0.0, 30.0, 60.0], [1.0, 1.0, 0.0], nyq=60.0)
         assert_array_almost_equal(taps1, taps2)
 
-
-class TestRemez(TestCase):
+class TestRemez(object):
 
     def test_bad_args(self):
         assert_raises(ValueError, remez, 11, [0.1, 0.4], [1], type='pooka')
@@ -399,6 +406,8 @@ class TestRemez(TestCase):
              -0.075943803756711, -0.041314581814658, 0.024590270518440]
         h = remez(12, [0, 0.3, 0.5, 1], [1, 0], Hz=2.)
         assert_allclose(h, k)
+        h = remez(12, [0, 0.3, 0.5, 1], [1, 0], fs=2.)
+        assert_allclose(h, k)
 
         h = [-0.038976016082299, 0.018704846485491, -0.014644062687875,
              0.002879152556419, 0.016849978528150, -0.043276706138248,
@@ -408,9 +417,10 @@ class TestRemez(TestCase):
              -0.043276706138248, 0.016849978528150, 0.002879152556419,
              -0.014644062687875, 0.018704846485491, -0.038976016082299]
         assert_allclose(remez(21, [0, 0.8, 0.9, 1], [0, 1], Hz=2.), h)
+        assert_allclose(remez(21, [0, 0.8, 0.9, 1], [0, 1], fs=2.), h)
 
 
-class TestFirls(TestCase):
+class TestFirls(object):
 
     def test_bad_args(self):
         # even numtaps
@@ -436,7 +446,7 @@ class TestFirls(TestCase):
         a = 0.1  # width of the transition band
 
         # design a halfband symmetric low-pass filter
-        h = firls(11, [0, a, 0.5-a, 0.5], [1, 1, 0, 0], nyq=0.5)
+        h = firls(11, [0, a, 0.5-a, 0.5], [1, 1, 0, 0], fs=1.0)
 
         # make sure the filter has correct # of taps
         assert_equal(len(h), N)
@@ -488,7 +498,7 @@ class TestFirls(TestCase):
         assert_allclose(taps, known_taps)
 
         # With linear changes:
-        taps = firls(7, (0, 1, 2, 3, 4, 5), [1, 0, 0, 1, 1, 0], nyq=10)
+        taps = firls(7, (0, 1, 2, 3, 4, 5), [1, 0, 0, 1, 1, 0], fs=20)
         # >> taps = firls(6, [0, 0.1, 0.2, 0.3, 0.4, 0.5], [1, 0, 0, 1, 1, 0])
         known_taps = [
             1.156090832768218, -4.1385894727395849, 7.5288619164321826,
@@ -496,8 +506,11 @@ class TestFirls(TestCase):
             1.156090832768218]
         assert_allclose(taps, known_taps)
 
+        taps = firls(7, (0, 1, 2, 3, 4, 5), [1, 0, 0, 1, 1, 0], nyq=10)
+        assert_allclose(taps, known_taps)
 
-class TestMinimumPhase(TestCase):
+
+class TestMinimumPhase(object):
 
     def test_bad_args(self):
         # not enough taps
@@ -507,9 +520,7 @@ class TestMinimumPhase(TestCase):
         assert_raises(ValueError, minimum_phase, 'foo')
         assert_raises(ValueError, minimum_phase, np.ones(10), n_fft=8)
         assert_raises(ValueError, minimum_phase, np.ones(10), method='foo')
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore")
-            assert_warns(RuntimeWarning, minimum_phase, np.arange(3))
+        assert_warns(RuntimeWarning, minimum_phase, np.arange(3))
 
     def test_homomorphic(self):
         # check that it can recover frequency responses of arbitrary
@@ -534,22 +545,19 @@ class TestMinimumPhase(TestCase):
         # f=[0 0.3 0.5 1];
         # a=[1 1 0 0];
         # h=remez(11,f,a);
-        h = remez(12, [0, 0.3, 0.5, 1], [1, 0], Hz=2.)
+        h = remez(12, [0, 0.3, 0.5, 1], [1, 0], fs=2.)
         k = [0.349585548646686, 0.373552164395447, 0.326082685363438,
              0.077152207480935, -0.129943946349364, -0.059355880509749]
         m = minimum_phase(h, 'hilbert')
-        assert_allclose(m, k, rtol=1e-3)
+        assert_allclose(m, k, rtol=2e-3)
 
         # f=[0 0.8 0.9 1];
         # a=[0 0 1 1];
         # h=remez(20,f,a);
-        h = remez(21, [0, 0.8, 0.9, 1], [0, 1], Hz=2.)
+        h = remez(21, [0, 0.8, 0.9, 1], [0, 1], fs=2.)
         k = [0.232486803906329, -0.133551833687071, 0.151871456867244,
              -0.157957283165866, 0.151739294892963, -0.129293146705090,
              0.100787844523204, -0.065832656741252, 0.035361328741024,
              -0.014977068692269, -0.158416139047557]
         m = minimum_phase(h, 'hilbert', n_fft=2**19)
-        assert_allclose(m, k, rtol=1e-3)
-
-if __name__ == "__main__":
-    run_module_suite()
+        assert_allclose(m, k, rtol=2e-3)
